@@ -1,4 +1,4 @@
-import logging, os.path
+import logging, os.path, tempfile
 import formish, schemaish, validatish
 from formish.filehandler import TempFileHandlerWeb
 from testish.lib import xformish
@@ -315,9 +315,9 @@ def File():
     A simple form with a single integer field
     """
     schema = schemaish.Structure()
-    schema.add('myFileField', schemaish.File())
+    schema.add('myFile', schemaish.File())
     form = formish.Form(schema, 'form')
-    form['myFileField'].widget = formish.FileUpload(filehandler=TempFileHandlerWeb())
+    form['myFile'].widget = formish.FileUpload(filehandler=TempFileHandlerWeb())
     return form
 
 def functest_File(self, sel):#{{{
@@ -325,15 +325,15 @@ def functest_File(self, sel):#{{{
 
     sel.click("form-action-submit")
     sel.wait_for_page_to_load("30000")
-    try: self.failUnless(sel.is_text_present("{'myFileField': None}"))
+    try: self.failUnless(sel.is_text_present("{'myFile': None}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
-    sel.type("form-myFileField", os.path.abspath("testdata/test.txt"))
+    sel.type("form-myFile", os.path.abspath("testdata/test.txt"))
     sel.click("form-action-submit")
     sel.wait_for_page_to_load("30000")
     
 
-    try: self.failUnless(sel.is_text_present("{'myFileField': <schemaish.type.File object at"))
+    try: self.failUnless(sel.is_text_present("{'myFile': <schemaish.type.File"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
     return#}}}
@@ -470,7 +470,9 @@ def MinLengthCheckboxMultiChoice():
     A checkbox multi choice with minimum length 3 (NOT WORKING)
     """
     schema = schemaish.Structure()
-    schema.add('multiChoice', schemaish.Sequence(schemaish.String(validation=validatish.Length(min=2))))
+    schema.add('multiChoice', schemaish.Sequence(
+        schemaish.String(validation=validatish.Length(min=2))
+        ))
     options = [(1,'a'),(2,'b'),(3,'c')]
 
     form = formish.Form(schema, 'form')
@@ -533,7 +535,10 @@ def All():
     Required and Plain Text (alphanum only plus _ and -)
     """
     schema = schemaish.Structure()
-    schema.add('requiredPlainText', schemaish.String(validator=validatish.All(validatish.Required(),validatish.PlainText(extra='-_'))))
+    schema.add('requiredPlainText', 
+           schemaish.String(validator=validatish.All(
+               validatish.Required(),validatish.PlainText(extra='-_')
+           )))
 
     form = formish.Form(schema, 'form')
     return form
@@ -553,6 +558,65 @@ def ValidationOnSequenceItem():
     form = formish.Form(schema, 'form')
     return form
 
+def RequiredStringAndFile():
+    """
+    A required string and a file field configured for image upload.
+    """
+    schema = schemaish.Structure()
+    schema.add('required', schemaish.String(validator=validatish.Required()))
+    schema.add('myFileField', schemaish.File())
+    form = formish.Form(schema, 'form')
+    form['myFileField'].widget = formish.FileUpload(filehandler=TempFileHandlerWeb(),show_image_preview=True,originalurl='/images/nouploadyet.png')
+    return form
+
+def functest_RequiredStringAndFile(self, sel):#{{{
+    sel.open("/RequiredStringAndFile")
+
+    sel.click("form-action-submit")
+    sel.wait_for_page_to_load("30000")
+        
+    try: self.assertEqual("", sel.get_value("myFileField.default"))
+    except AssertionError, e: self.verificationErrors.append(str(e))
+
+    try: self.assertEqual("", sel.get_value("myFileField.name"))
+    except AssertionError, e: self.verificationErrors.append(str(e))
+
+
+    sel.type("form-myFileField", os.path.abspath("testdata/photo.png"))
+    sel.click("form-action-submit")
+    sel.wait_for_page_to_load("30000")
+        
+    try: self.assertEqual("", sel.get_value("myFileField.default"))
+    except AssertionError, e: self.verificationErrors.append(str(e))
+
+    try: self.assertEqual("-photo.png", sel.get_value("myFileField.name")[-10:])
+    except AssertionError, e: self.verificationErrors.append(str(e))
+
+    sel.click("form-action-submit")
+    sel.wait_for_page_to_load("30000")
+        
+    try: self.assertEqual("", sel.get_value("myFileField.default"))
+    except AssertionError, e: self.verificationErrors.append(str(e))
+
+    try: self.assertEqual("-photo.png", sel.get_value("myFileField.name")[-10:])
+    except AssertionError, e: self.verificationErrors.append(str(e))
+
+    sel.type("form-myFileField", os.path.abspath("testdata/photo.jpg"))
+    sel.type("form-required", 'foo')
+    sel.click("form-action-submit")
+    sel.wait_for_page_to_load("30000")
+
+    try: self.assertEqual(sel.get_attribute("//div[@id='actual']/img@src")[-9:],"photo.jpg")
+    except AssertionError, e: self.verificationErrors.append(str(e))
+    try: self.assertEqual(sel.get_attribute("//div[@id='resized']/img@src")[-22:-13],"photo.jpg")
+    except AssertionError, e: self.verificationErrors.append(str(e))
+
+    try: self.assertEqual("300", sel.get_text("css=#actual div"))
+    except AssertionError, e: self.verificationErrors.append(str(e))
+    try: self.assertEqual("100", sel.get_text("css=#resized div"))
+    except AssertionError, e: self.verificationErrors.append(str(e))
+          
+    return#}}}
 
 ########################
 #
@@ -679,7 +743,10 @@ def CheckboxMultiChoiceTree():
     """
     schema = schemaish.Structure()
     schema.add('multiChoice', schemaish.Sequence(schemaish.String()))
-    options = [('a','Top Level A'),('a.x','Second Level X'),('a.y','Second Level Y'),('b','First Level B')]
+    options = [('a','Top Level A'),
+               ('a.x','Second Level X'),
+               ('a.y','Second Level Y'),
+               ('b','First Level B')]
 
     form = formish.Form(schema, 'form')
     form['multiChoice'].widget = formish.CheckboxMultiChoiceTree(options)
@@ -768,8 +835,11 @@ def functest_SequenceOfUploadStructures(self, sel):#{{{
     sel.type("form-myList-0-b", "13")
     sel.click("form-action-submit")
     sel.wait_for_page_to_load("30000")
+    import time; time.sleep(10)
 
-    try: self.failUnless(sel.is_text_present("{'myList': [{'a': <schemaish.type.File object at *, 'b': 13}]}"))
+    try: self.failUnless(sel.is_text_present("{'myList': [{'a': <schemaish.type.File"))
+    except AssertionError, e: self.verificationErrors.append(str(e))
+    try: self.failUnless(sel.is_text_present("'b': 13}]}"))
     except AssertionError, e: self.verificationErrors.append(str(e))
 
     return#}}}
@@ -862,7 +932,9 @@ def GranularFormLayout():
     """
 
     schema = schemaish.Structure()
-    schema.add( 'firstName', schemaish.String(title='First Name',description='The name before your last one',validator=validatish.Required()) )
+    schema.add( 'firstName', schemaish.String(title='First Name', \
+                     description='The name before your last one', \
+                     validator=validatish.Required()) )
 
     form = formish.Form(schema, 'form')
 
