@@ -1,6 +1,11 @@
 import logging
+import os.path
+import magic
+from datetime import datetime
+import tempfile
 from restish import resource, templating
 import formish
+from formish import fileresource
 
 from pprint import pformat
 
@@ -30,6 +35,44 @@ def get_forms(ids):
     return out
 
 
+
+class FileAccessor(object):
+    """
+    A skeleton class that should be implemented so that the files resource can
+    build caches, etc
+    """
+
+    def __init__(self):
+        self.prefix = 'store-%s'%tempfile.gettempprefix()
+        self.tempdir = tempfile.gettempdir()
+
+
+    def get_mimetype(self, filename):
+        """
+        Get the mime type of the file with this id
+        """
+        actualfilename = '%s/%s%s'% (self.tempdir, self.prefix, filename.split('-')[-1])
+        return magic.from_file(actualfilename, mime=True)
+
+
+    def get_mtime(self, filename):
+        actualfilename = '%s/%s%s'% (self.tempdir, self.prefix, filename.split('-')[-1])
+        return datetime.fromtimestamp( os.path.getmtime(actualfilename) )
+
+
+    def get_file(self, filename):
+        """
+        Get the file object for this id
+        """
+        actualfilename = '%s/%s%s'% (self.tempdir, self.prefix, filename.split('-')[-1])
+        return open(actualfilename).read()
+
+    def file_exists(self, filename):
+        actualfilename = '%s/%s%s'% (self.tempdir, self.prefix, filename.split('-')[-1])
+        return os.path.exists(actualfilename)
+
+
+
 class Root(resource.Resource):
 
     @resource.GET()
@@ -39,7 +82,7 @@ class Root(resource.Resource):
     
     def resource_child(self, request, segments):
         if segments[0] == 'filehandler':
-            return formish.fileresource.FileResource(), segments[1:]
+            return fileresource.FileResource(fileaccessor=FileAccessor(),segments=segments[1:]), ()
         return FormResource(segments[0]), segments[1:]
 
 
@@ -69,7 +112,7 @@ class FormResource(resource.Resource):
             form = self.form_getter()
             form.renderer = request.environ['restish.templating.renderer']
         return {'title': self.title, 'description': self.description,
-                'form': form, 'data': pformat(data),
+                'form': form, 'data': pformat(data),'rawdata': data,
                 'template': extract_function.extract_docstring('template_%s'%self.id),
                 'template_highlighted': extract_function.extract_docstring_highlighted('template_%s'%self.id),
                 'definition': extract_function.extract(self.id),
@@ -84,4 +127,15 @@ class FormResource(resource.Resource):
         except formish.FormError, e:
             return self.render_form(request, form=form)
         else:
+            if 'myFileField' in data:
+                f = data['myFileField']
+                filedata = f.file.read()
+                prefix = 'store-%s'%tempfile.gettempprefix()
+                tempdir = tempfile.gettempdir()
+                actualfilename = '%s/%s%s'% (tempdir, prefix, f.filename.split('-')[-1])
+                out = open(actualfilename,'w')
+                out.write(filedata)
+                out.close()
+                form['myFileField'].widget.filehandler.delete_file(f.filename)
+                
             return self.render_form(request, form=None, data=data)
